EXPORTS
	?__DbgCheckHeap@RRemConBulk@@QAEHH@Z @ 1 NONAME ; int RRemConBulk::__DbgCheckHeap(int)
	??0RRemConBulk@@QAE@XZ @ 2 NONAME ; RRemConBulk::RRemConBulk(void)
	?Receive@RRemCon@@QAEXAAVTRequestStatus@@AAUTRemConClientReceivePackage@@AAVTDes8@@@Z @ 3 NONAME ; void RRemCon::Receive(class TRequestStatus &, struct TRemConClientReceivePackage &, class TDes8 &)
	?__DbgMarkHeap@RRemCon@@QAEHXZ @ 4 NONAME ; int RRemCon::__DbgMarkHeap(void)
	?Version@RRemCon@@QBE?AVTVersion@@XZ @ 5 NONAME ; class TVersion RRemCon::Version(void) const
	?DisconnectBearerCancel@RRemConController@@QAEHXZ @ 6 NONAME ; int RRemConController::DisconnectBearerCancel(void)
	?Receive@RRemConBulk@@QAEXAAVTRequestStatus@@AAVTUid@@AAIAAVTDes8@@@Z @ 7 NONAME ; void RRemConBulk::Receive(class TRequestStatus &, class TUid &, unsigned int &, class TDes8 &)
	?SendCancel@RRemConBulk@@QAEHXZ @ 8 NONAME ; int RRemConBulk::SendCancel(void)
	?ReceiveCancel@RRemConBulk@@QAEHXZ @ 9 NONAME ; int RRemConBulk::ReceiveCancel(void)
	?ReceiveCancel@RRemCon@@QAEHXZ @ 10 NONAME ; int RRemCon::ReceiveCancel(void)
	?Send@RRemConBulk@@QAEXAAVTRequestStatus@@VTUid@@IABVTDesC8@@@Z @ 11 NONAME ; void RRemConBulk::Send(class TRequestStatus &, class TUid, unsigned int, class TDesC8 const &)
	?ConnectBearerCancel@RRemConController@@QAEHXZ @ 12 NONAME ; int RRemConController::ConnectBearerCancel(void)
	?NotifyConnectionsChange@RRemCon@@QAEXAAVTRequestStatus@@@Z @ 13 NONAME ; void RRemCon::NotifyConnectionsChange(class TRequestStatus &)
	?__DbgMarkEnd@RRemConBulk@@QAEHH@Z @ 14 NONAME ; int RRemConBulk::__DbgMarkEnd(int)
	?RegisterInterestedAPIs@RRemCon@@QAEHABVTDesC8@@@Z @ 15 NONAME ; int RRemCon::RegisterInterestedAPIs(class TDesC8 const &)
	?SendUnreliable@RRemConBulk@@QAEHVTUid@@IABVTDesC8@@@Z @ 16 NONAME ; int RRemConBulk::SendUnreliable(class TUid, unsigned int, class TDesC8 const &)
	?Connect@RRemCon@@QAEHXZ @ 17 NONAME ; int RRemCon::Connect(void)
	?Connect@RRemConBulk@@QAEHXZ @ 18 NONAME ; int RRemConBulk::Connect(void)
	?DisconnectBearer@RRemConController@@QAEXAAVTRequestStatus@@@Z @ 19 NONAME ; void RRemConController::DisconnectBearer(class TRequestStatus &)
	?GetConnections@RRemCon@@QAEHAAV?$TSglQue@VTRemConAddress@@@@@Z @ 20 NONAME ; int RRemCon::GetConnections(class TSglQue<class TRemConAddress> &)
	?Connect@RRemCon@@QAEHABW4TPlayerType@@ABW4TPlayerSubType@@ABVTDesC8@@@Z @ 21 NONAME ; int RRemCon::Connect(enum TPlayerType const &, enum TPlayerSubType const &, class TDesC8 const &)
	?Version@RRemConBulk@@QBE?AVTVersion@@XZ @ 22 NONAME ; class TVersion RRemConBulk::Version(void) const
	?ConnectBearer@RRemConController@@QAEXAAVTRequestStatus@@@Z @ 23 NONAME ; void RRemConController::ConnectBearer(class TRequestStatus &)
	??0RRemConTarget@@QAE@XZ @ 24 NONAME ; RRemConTarget::RRemConTarget(void)
	?GoConnectionless@RRemConController@@QAEHXZ @ 25 NONAME ; int RRemConController::GoConnectionless(void)
	?__DbgFailNext@RRemCon@@QAEHH@Z @ 26 NONAME ; int RRemCon::__DbgFailNext(int)
	?__DbgFailNext@RRemConBulk@@QAEHH@Z @ 27 NONAME ; int RRemConBulk::__DbgFailNext(int)
	?SendCancel@RRemCon@@QAEHXZ @ 28 NONAME ; int RRemCon::SendCancel(void)
	?GoConnectionOriented@RRemConController@@QAEHABVTRemConAddress@@@Z @ 29 NONAME ; int RRemConController::GoConnectionOriented(class TRemConAddress const &)
	?Send@RRemCon@@QAEXAAVTRequestStatus@@VTUid@@IAAIW4TRemConMessageSubType@@ABVTDesC8@@@Z @ 30 NONAME ; void RRemCon::Send(class TRequestStatus &, class TUid, unsigned int, unsigned int &, enum TRemConMessageSubType, class TDesC8 const &)
	?NotifyConnectionsChangeCancel@RRemCon@@QAEHXZ @ 31 NONAME ; int RRemCon::NotifyConnectionsChangeCancel(void)
	?__DbgMarkHeap@RRemConBulk@@QAEHXZ @ 32 NONAME ; int RRemConBulk::__DbgMarkHeap(void)
	?SendNotify@RRemCon@@QAEXAAVTRequestStatus@@VTUid@@IW4TRemConMessageSubType@@ABVTDesC8@@@Z @ 33 NONAME ; void RRemCon::SendNotify(class TRequestStatus &, class TUid, unsigned int, enum TRemConMessageSubType, class TDesC8 const &)
	?SendUnreliable@RRemCon@@QAEHVTUid@@IW4TRemConMessageSubType@@ABVTDesC8@@@Z @ 34 NONAME ; int RRemCon::SendUnreliable(class TUid, unsigned int, enum TRemConMessageSubType, class TDesC8 const &)
	?__DbgMarkEnd@RRemCon@@QAEHH@Z @ 35 NONAME ; int RRemCon::__DbgMarkEnd(int)
	??0RRemConController@@QAE@XZ @ 36 NONAME ; RRemConController::RRemConController(void)
	?__DbgCheckHeap@RRemCon@@QAEHH@Z @ 37 NONAME ; int RRemCon::__DbgCheckHeap(int)

